@@ -62,7 +62,7 @@ emuia_download = function(commune = NULL, TERYT = NULL, outdir = ".",
 
     if (any(status %in% c("error", "warning"))) {
       err_print()
-      return("connection error")
+      return(invisible("connection error"))
     }
 
     if (unzip) {
