@@ -55,7 +55,7 @@ geonames_download = function(type, format = "SHP", outdir = ".", unzip = TRUE, .
 
     if (any(status %in% c("error", "warning"))) {
       err_print()
-      return("connection error")
+      return(invisible("connection error"))
     }
 
     if (unzip) {
